#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor qv4l2%{nil}
%if "%{flavor}" == "qv4l2"
%global psuffix -%{flavor}
%endif
%define _udevdir %(pkg-config --variable udevdir udev)
%define so_ver 0
%define sname v4l-utils
Name:           v4l-utils%{?psuffix}
Version:        1.24.1
Release:        1.7
Summary:        Utilities for video4linux
License:        GPL-2.0-only AND GPL-2.0-or-later AND LGPL-2.1-or-later
URL:            https://linuxtv.org/downloads/v4l-utils/
Source0:        https://linuxtv.org/downloads/v4l-utils/%{sname}-%{version}.tar.bz2
Source1:        https://linuxtv.org/downloads/v4l-utils/%{sname}-%{version}.tar.bz2.asc
Source2:        %{sname}.keyring
Source100:      baselibs.conf
Patch0:         use_system_v4l_for_qv4l.patch
Patch1:         v4l-utils-32bitfix.patch
BuildRequires:  alsa-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libjpeg-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(udev)
Requires:       libv4l = %{version}
%if "%{flavor}" == ""
BuildRequires:  doxygen
BuildRequires:  kernel-headers
%endif
%if "%{flavor}" == "qv4l2"
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(libv4l2)
BuildRequires:  pkgconfig(libv4lconvert)
%endif

%description
v4l-utils is a collection of various video4linux (V4L) utilities.

%lang_package

%package devel-tools
Summary:        Utilities for v4l2 / DVB driver development and debugging
License:        GPL-2.0-only AND GPL-2.0-or-later
Requires:       libv4l = %{version}

%description devel-tools
Utilities for v4l2 / DVB driver authors for development and debugging.

%package -n dvb-utils
Summary:        Utilities for DVB devices
License:        GPL-2.0-only
Recommends:     dtv-scan-tables-v5

%description -n dvb-utils
dvb-utils is a collection of various DVB utilities.

%package -n libdvbv5-%{so_ver}
Summary:        Library that provides access to DVB adapter cards
License:        GPL-2.0-only

%description -n libdvbv5-%{so_ver}
libdvbv5 is a library meant to be used by digital TV applications that need to
talk with media hardware.

This package contains shared lib for packages that use libdvbv5.

%package -n libdvbv5-devel
Summary:        Development files for libdvbv5
License:        GPL-2.0-only
Requires:       libdvbv5-%{so_ver} = %{version}

%description -n libdvbv5-devel
The libdvbv5-devel package contains libraries and header files for
developing applications that use libdvbv5.

%package -n libv4l
Summary:        Collection of video4linux support libraries
License:        GPL-2.0-only AND LGPL-2.1-or-later

%description -n libv4l
libv4l is a collection of libraries which adds a thin abstraction layer on
top of video4linux2 devices. The purpose of this (thin) layer is to make it
easy for application writers to support a wide variety of devices without
having to write separate code for different devices in the same class.

%package -n libv4l1-%{so_ver}
Summary:        Video4linux support library
License:        LGPL-2.1-or-later
Requires:       libv4l

%description -n libv4l1-%{so_ver}
libv4l1 offers the (deprecated) v4l1 API on top of v4l2 devices, independent
of the drivers for those devices supporting v4l1 compatibility (which many
v4l2 drivers do not).

This package contains shared lib for packages that use libv4l1.

%package -n libv4l2-%{so_ver}
Summary:        Video4linux support library
License:        LGPL-2.1-or-later
Requires:       libv4l

%description -n libv4l2-%{so_ver}
libv4l2 offers the v4l2 API on top of v4l2 devices, while adding for the
application transparent libv4lconvert conversion where necessary.

This package contains shared lib for packages that use libv4l2.

%package -n libv4l2rds%{so_ver}
Summary:        Video4linux support library
License:        LGPL-2.1-or-later
Requires:       libv4l

%description -n libv4l2rds%{so_ver}
libv4l2rds offers decoding raw RDS data from V4L2 Radio devices and simple ways
to access the received RDS information.

This package contains shared lib for packages that use libv4l2rds.

%package -n libv4lconvert%{so_ver}
Summary:        Video4linux support library
License:        LGPL-2.1-or-later
Requires:       libv4l

%description -n libv4lconvert%{so_ver}
libv4lconvert offers functions to convert from any (known) pixel-format
to V4l2_PIX_FMT_BGR24 or V4l2_PIX_FMT_YUV420.

This package contains shared lib for packages that use libv4lconvert.

%package -n libv4l-devel
Summary:        Development files for libv4l
License:        LGPL-2.1-or-later
Requires:       libv4l1-%{so_ver} = %{version}
Requires:       libv4l2-%{so_ver} = %{version}
Requires:       libv4l2rds%{so_ver} = %{version}
Requires:       libv4lconvert%{so_ver} = %{version}

%description -n libv4l-devel
The libv4l-devel package contains libraries and header files for
developing applications that use libv4l.

%package -n     qv4l2
Summary:        Video4linux test control and streaming test application
License:        GPL-2.0-or-later
Requires:       libv4l = %{version}

%description -n qv4l2
qv4l2 is a test control and streaming test application for video4linux.

%prep
%autosetup -p1 -n %{sname}-%{version}

%build
autoreconf -vfi
%configure \
  --disable-static \
  --disable-silent-rules \
%if "%{flavor}" == "qv4l2"
  --disable-libdvbv5 \
%else
  --disable-qv4l2 \
%endif
  --with-udevdir=%{_udevdir}

%if "%{flavor}" == "qv4l2"
export CXXFLAGS="-std=c++14 %{optflags}"
%make_build -C utils/libmedia_dev
%make_build -C utils/libv4l2util
%make_build -C utils/qv4l2
%else
%make_build
%endif

%install
%if "%{flavor}" == "qv4l2"
%make_install -C utils/qv4l2
%suse_update_desktop_file -N "QV4l2" -G "V4L2 Test Utility" -r qv4l2 Qt AudioVideo Video TV

%else
%make_install
%find_lang "%{name}"
%find_lang libdvbv5

# Not needed (links to plugins in libv4l subdir)
rm %{buildroot}%{_libdir}/{v4l1compat.so,v4l2convert.so}
%endif

find %{buildroot} -type f -name "*.la" -delete -print

%if "%{flavor}" == ""
%post -n libdvbv5-%{so_ver} -p /sbin/ldconfig
%postun -n libdvbv5-%{so_ver} -p /sbin/ldconfig
%post -n libv4l1-%{so_ver} -p /sbin/ldconfig
%postun -n libv4l1-%{so_ver} -p /sbin/ldconfig
%post -n libv4l2-%{so_ver} -p /sbin/ldconfig
%postun -n libv4l2-%{so_ver} -p /sbin/ldconfig
%post -n libv4l2rds%{so_ver} -p /sbin/ldconfig
%postun -n libv4l2rds%{so_ver} -p /sbin/ldconfig
%post -n libv4lconvert%{so_ver} -p /sbin/ldconfig
%postun -n libv4lconvert%{so_ver} -p /sbin/ldconfig
%endif

%if "%{flavor}" == ""
%files
%license COPYING
%doc ChangeLog README.md TODO
%dir %{_sysconfdir}/rc_keymaps/
%config(noreplace) %{_sysconfdir}/rc_maps.cfg
%{_udevdir}/rc_keymaps
%{_udevrulesdir}/70-infrared.rules
%{_bindir}/cx18-ctl
%{_bindir}/cec-compliance
%{_bindir}/cec-ctl
%{_bindir}/cec-follower
%{_bindir}/ir-ctl
%{_bindir}/ir-keytable
%{_bindir}/ivtv-ctl
%{_bindir}/media-ctl
%{_bindir}/rds-ctl
%{_bindir}/v4l2-ctl
%{_bindir}/v4l2-sysfs-path
%{_mandir}/man5/rc_keymap.5%{?ext_man}
%{_mandir}/man1/ir-keytable.1%{?ext_man}
%{_mandir}/man1/v4l2-ctl.1%{?ext_man}
%{_mandir}/man1/cec-compliance.1%{?ext_man}
%{_mandir}/man1/cec-ctl.1%{?ext_man}
%{_mandir}/man1/cec-follower.1%{?ext_man}
%{_mandir}/man1/ir-ctl.1%{?ext_man}

%files lang -f "%{name}.lang"

%files devel-tools
%license COPYING
%doc ChangeLog README.md TODO
%{_bindir}/decode_tm6000
%{_bindir}/v4l2-compliance
%{_sbindir}/v4l2-dbg
%{_mandir}/man1/v4l2-compliance.1%{?ext_man}

%files -n dvb-utils
%license COPYING
%doc ChangeLog README.md TODO
%{_bindir}/dvb-*
%{_bindir}/dvbv5-*
%{_mandir}/man1/dvb-*1%{?ext_man}
%{_mandir}/man1/dvbv5-*1%{?ext_man}

%files -n libdvbv5-%{so_ver} -f libdvbv5.lang
%{_libdir}/libdvbv5.so.%{so_ver}*

%files -n libdvbv5-devel
%license COPYING.libdvbv5
%doc TODO.libdvbv5
%{_includedir}/libdvbv5/
%{_libdir}/libdvbv5.so
%{_libdir}/pkgconfig/libdvbv5*.pc

%files -n libv4l
%license COPYING.libv4l
%doc ChangeLog README.md README.libv4l TODO
%{_libdir}/libv4l/

%files -n libv4l1-%{so_ver}
%{_libdir}/libv4l1.so.%{so_ver}*

%files -n libv4l2-%{so_ver}
%{_libdir}/libv4l2.so.%{so_ver}*

%files -n libv4l2rds%{so_ver}
%{_libdir}/libv4l2rds.so.%{so_ver}*

%files -n libv4lconvert%{so_ver}
%{_libdir}/libv4lconvert.so.%{so_ver}*

%files -n libv4l-devel
%license COPYING.libv4l
%doc README.lib-multi-threading
%{_includedir}/libv4l*.h
%{_libdir}/libv4l*.so
%{_libdir}/pkgconfig/libv4l*.pc
%endif

%if "%{flavor}" == "qv4l2"
%files -n qv4l2
%license COPYING
%doc ChangeLog README.md TODO
%{_bindir}/qv4l2
%{_datadir}/applications/qv4l2.desktop
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/??x??
%dir %{_datadir}/icons/hicolor/??x??/apps
%dir %{_datadir}/icons/hicolor/scalable
%dir %{_datadir}/icons/hicolor/scalable/apps
%{_datadir}/icons/hicolor/*/apps/qv4l2.*
%{_mandir}/man1/qv4l2.1%{?ext_man}
%endif

%changelog
* Wed Mar  1 2023 Asterios Dramis <asterios.dramis@gmail.com>
- Update to version 1.24.1:
  * Lot of changes, see ChangeLog for details.
- Removed update-desktop-files and hicolor-icon-theme post
  requirements (not needed anymore).
* Sun Dec  5 2021 Dirk Müller <dmueller@suse.com>
- update to 1.22.1
  * add missing include for uClibc-ng
  * buildsystem: Start v4l-utils 1.21.0 development cycle
  * Build with libbpf, remove local sources
  * cec: add active sensing test for Audio Rate Control messages
  * cec: add Deck Control wake-up handling tests
  * cec: add invalid operand test for Audio Rate Control messages
  * cec: add One Touch Record Standby tests
  * cec: add tests for Deck Control message
  * cec: add tests for Deck Play message
  * cec: add tests for Give Deck Status message
  * cec-compliance: add Audio System mask to Set Audio Rate
  * cec-compliance: add cec-test-tuner-record-timer.cpp
  * cec-compliance: add 'reason' sanity check.
  * cec-compliance: Add version command
  * cec-compliance: clarify a power transition test
  * cec-compliance: clarify a warning
  * cec-compliance: don't skip tests if phys addr is invalid
  * cec-compliance: fix broken timer tests
  * cec-compliance: fix confusing 'Transient state' message
  * cec-compliance: fix 'unresponsive' detection
  * cec-compliance/follower: fix type comparison warnings
  * cec-compliance: hardcode audio_out_delay to 1 if not set
  * cec-compliance: improve confusing message
  * cec-compliance: improve current latency checks
  * cec-compliance: improve error message
  * cec-compliance: improve testLostMsgs test
  * cec-compliance: improve warning about late reply
  * cec-compliance: move audio helper functions to cec-test-audio.cpp
  * cec-compliance: move CDC helper functions to cec-test.cpp
  * cec-compliance: options -n and -N were swapped in --help
  * cec-compliance: remove Deck Status test
  * cec-compliance: remove One Touch Record Status test
  * cec-compliance: skip warning if audio_out_delay is 1
  * cec-compliance: the SHA needs to be shown in different ways
  * cec-compliance: use send_timer_error for one more test
  * cec-compliance: use the actual audio_out_delay value
  * cec-compliance: wait up to 10s for Inactive Source reply
  * cec-ctl.1.in: fix awkward language
  * cec-ctl: Add version command
  * cec-ctl/cec-compliance: add pulse8-cec kernel version check
  * cec-ctl: detect if Standby etc. messages are Nacked
  * cec-ctl: don't spam log with PA changes unless paused
  * cec-ctl: free signal time -> signal free time
  * cec-ctl: improve --list-devices
  * cec-ctl: improve 'Sleep' message in stress test
  * cec-ctl: improve the --phys-addr-from-edid-poll option
  * cec-ctl: log signal free time when (show && !verbose)
  * cec-ctl: min/max-sleep arguments should be double, not unsigned
  * cec-ctl: really wait for 2 seconds when the HPD is low
  * cec-ctl: report low drive without --verbose
  * cec-ctl: showTopology(): fix level wraparound bug
  * cec: expand One Touch Record tests
  * cec: expand Timer Programming tests
  * cec-follower: add --standby and --toggle-power-status
  * cec-follower: Add version command
  * cec-follower: CEC_MSG_STANDBY can just call enter_standby()
  * cec-follower: detect the cessation of Audio Rate Control messages
  * cec-follower: drop physical address check
  * cec-follower: emulate features for CEC versions < CEC 2.0
  * cec-follower: emulate programmed timer recordings
  * cec-follower: fix incorrect fallthrough
  * cec-follower: fix logging the SHA
  * cec-follower: increase precision of Audio Rate Control active sensing
  * cec-follower: refactoring: split up overly long functions
  * cec-follower: use log_addr_type to get local device type
  * cec: improve vendor ID logging
  * cec: remove redundant struct cec_msg initializations
  * cec-tuner: std::array conversions
  * cec utils and v4l2-compliance: improve version info
  * clang-tidy: add a bunch of const
  * clang-tidy: use auto
  * clang-tidy: use nullptr
  * clang-tidy: use using instead of typedef
  * clean up includes and convert C includes to C++
  * common/media-info.cpp: 'Flags' was not aligned
  * configure.ac: Add --without-libudev option to avoid automagic dep
  * configure.ac: autodetect availability of systemd
  * configure.ac: drop printf for GIT_COMMIT_DATE
  * configure.ac: Export git commit count
  * configure.ac: Fix building without libudev
  * configure.ac: improve gettext compatibility support
  * configure.ac: Resolve GIT_* even if repository is a submodule
  * configure.ac: revert AM_GNU_GETTEXT_VERSION change
  * contrib/test/test-media: add -setup option
  * convert files to reference
  * convert to range based loops
  * cppcheck: turn several references to const
  * cppcheck: use const references
  * cv4l-helpers.h: fix the cv4l_buffer assignment operator
  * dvb-dev-remote: check if setsockopt() fails
  * dvb-fe-tool: better check the event type
  * dvb-file: fix one-line output with default values
  * dvb-file: reimplement get_pmt_descriptors()
  * dvbv5-daemon: don't dereference a null pointer
  * dvbv5-daemon: do some cleanups at the daemon
  * dvbv5-zap: add a check for dvb_fe_retrieve_status() errors
  * dvbv5-zap: add a warning when not recording PMT data
  * dvbv5-zap: allow recording also the SDT table
  * dvbv5-zap: don't use start time initialized
  * dvbv5-zap: fix a cut-and paste error
  * dvbv5-zap: remove an unused logic
  * dvb-zap: copy_to_file doesn't return any value
  * fix mismatching declaration
  * Fix print formatting warning for clang.
  * ir-ctl: include timeout in raw IR and parse timeout in pulse-space file
  * ir-ctl: increase the size of the buffer used to read raw files
  * ir-ctl: print correct transmitter count
  * ir-ctl: Revert "ir-ctl: print correct transmitter count"
  * keytable: Add source information in generated keymaps
  * keytable: ensure BPF IR decoders use correct section name
  * keytable: Fix missing inclusion of argp.h
  * keytable: fix typo
  * keytable: restrict installation of 50-rc_keymap.conf
  * libcecutil/cec-info.cpp: rename Reserved to Backup
  * libcecutil: make license consistent
  * libdvb: fix ATSC service location parser
  * libdvbv5: add a warning if a descriptor's init doesn't went fine
  * libdvbv5: add support for the registration descriptor
  * libdvbv5: avoid a potential access out of an array
  * libdvbv5: desc_ca: cleanup the routine
  * libdvbv5: desc_language: check if the size is correct
  * libdvbv5: desc_network_name: simplify the init code
  * libdvbv5: detect SMTPE 302m audio format
  * libdvbv5: don't leak memory at dvb-dev-remote
  * libdvbv5: dvb-dev-local: better handle realloc()
  * libdvbv5: dvb-dev-local: fix error handling for device addition
  * libdvbv5: dvb-dev-remote: better handle cmd size
  * libdvbv5: dvb-dev-remote: don't leak resources at send_buf()
  * libdvbv5: fix a typo
  * libdvbv5: fix init of the ATSC service location
  * libdvbv5: fix the quality detection logic
  * libdvbv5: hide my_strlcpy symbol
  * libdvbv5: hide stack_dump symbols and provide soname compatibility
  * libdvbv5: initialize v3 params
  * libdvbv5: use an array for the fourcc type
  * libdvbv5: validate cable descriptor's size
  * libv4l2: add newer caps to v4l2_driver.c
  * Makefile.am: turn the build less verbose by default
  * mass constexpr conversions
  * mc_nextgen_test: Link against argp library
  * media-ctl: add v4l2-ycbcr-enc field in help description
  * media-ctl: Add version command
  * media-ctl: fix compiler warnings
  * media-ctl: fix ycbcr property in help description
  * media-info: MEDIA_ENT_F_IO_DTV doesn't need an interface
  * Move sync-with-kernel into dedicated shell script ./sync-with-kernel.sh
  * qv4l2: add -Wno-psabi to avoid ABI warning on ARM
  * qv4l2: Also fall back to old method for querying resolution
  * qv4l2: fallback if window()->windowHandle() == NULL
  * qv4l2: fix CaptureWin::setWindowSize() if there are multiple screens
  * qv4l2: fix more 'deprecated Qt functions' warnings
  * qv4l2: fix use of deprecated byteCount method
  * qv4l2: QGuiApplication::screenAt() appeared in Qt 5.10
  * qvidcap: fix GL_UNPACK_ROW_LENGTH for Bayer > 8 bits
  * qvidcap: set GL_UNPACK_ROW_LENGTH for Bayer formats
  * remove pointless constructor
  * remove unused ARRAY_SIZE
  * Rudimentary support for mi_media_detect_type on FreeBSD.
  * sync with latest media kernel
  * test-media: add 'date' at beginning and end, show versions
  * test-media: add -E and -W options
  * test-media: add support for vidtv
  * test-media: add 'tee /dev/kmsg'
  * test-media: add vidtv to the mc target
  * test-media: also keep vivid cec devices open
  * test-media: configure vimc scaler correctly
  * test-media: drop vidtv from mc, but warn if MC is disabled for DVB
  * test-media: drop vidtv from the 'mc' target
  * test-media: enable cache_hints for the first vivid instance
  * test-media: improve vidtv tests
  * test-media: mc should include vidtv
  * test-media: missed one scaler config line
  * test-media: show version info earlier and show cmd args
  * use auto
  * use emplace_back
  * use explicit for single argument constructors
  * Use standard integer types
  * use using instead of typedef
  * utils/cec: fix inconsistent Vendor ID reporting
  * utils/libcecutil/cec-log.cpp: report 6 digits of Vendor ID
  * utils: replace push_back with emplace_back
  * utils: v4l2-ctl: support V4L2_CAP_IO_MC in v4l2-ctl '--list-formats-*' commands
  * v4l2/cec-compliance: use new GIT_SHA variable
  * v4l2: common: add the flags V4L2_FMT_FLAG_CSC* to the list that maps flags to str
  * v4l2-compliance-32: use v4l2_compliance_CPPFLAGS
  * v4l2-compliance: add 0 check for v4l2_event reserved field
  * v4l2-compliance: Add libcamera to businfo prefixes
  * v4l2-compliance: add missing V4L2_PIX_FMT_H264_SLICE
  * v4l2-compliance: add new test for 32/64 bit time handling
  * v4l2-compliance: add support for VIDIOC_SUBDEV_QUERYCAP
  * v4l2-compliance: Add version command
  * v4l2-compliance: check correct buffer length after CREATE_BUFS
  * v4l2-compliance: check entity function for codecs
  * v4l2-compliance: Convert testBlockingDQBuf to pthreads
  * v4l2-compliance: disable cache flag test for kernels < 5.9
  * v4l2-compliance: don't warn about seq counter for metadata
  * v4l2-compliance: drop kernel_version
  * v4l2-compliance: fix bad indentation
  * v4l2-compliance: fix cache hint regressions
  * v4l2-compliance: fix colorspace checks for JPEG codecs
  * v4l2-compliance: fix g++-7 compile error
  * v4l2-compliance: fix stateful encoder tests
  * v4l2-compliance: fix two S_EDID tests
  * v4l2-compliance: improve comment for CROPCAP/G_SELECTION fail
  * v4l2-compliance: improve compound control checks
  * v4l2-compliance: improve fmtdesc.description check
  * v4l2-compliance: improve frequency range checks
  * v4l2-compliance: improve request tests
  * v4l2-compliance: improve VIDIOC_TRY_DE/ENCODER_CMD tests
  * v4l2-compliance: improve VIDIOC_(TRY_)EN/DECODER_CMD tests
  * v4l2-compliance: move all vivid controls to v4l2-compliance.h
  * v4l2-compliance: relax testBasicSelection check.
  * v4l2-compliance: remove spurious \n in message
  * v4l2-compliance: rename stvec to vec_remote_subtests
  * v4l2-compliance: skip sequence tests for vivid
  * v4l2-compliance: some fails were ignored
  * v4l2-compliance: test for vb2/m2m poll kernel bug
  * v4l2-compliance: test polling and disconnecting
  * v4l2-compliance: use fail_on_test_val for better fail reports
  * v4l2-compliance: V4L2_PIX_FMT_VP8_FRAME is for stateless decoder
  * v4l2-ctl-32: use v4l2_ctl_CPPFLAGS, fix wrong check
  * v4l2-ctl: add missing const, use {} instead of memset
  * v4l2-ctl: add new control types
  * v4l2-ctl: add '--set-edid type=list' support
  * v4l2-ctl: add --show-edid, add new test EDIDs
  * v4l2-ctl: add support for VIDIOC_SUBDEV_QUERYCAP
  * v4l2-ctl: Add version command
  * v4l2-ctl: break on VIDIOC_DQEVENT error
  * v4l2-ctl: clean up control value printing
  * v4l2-ctl: don't squash setting multiple identical controls.
  * v4l2-ctl: fix broken fd.qbuf error check
  * v4l2-ctl: fix bugs found in streaming_set_cap2out
  * v4l2-ctl: fix hdmi and hdmi-4k-170mhz EDIDs
  * v4l2-ctl: fix incorrect check for last_ts
  * v4l2-ctl: fix INTEGER64 support, add common_print_control()
  * v4l2-ctl: Fix test_ioctl cmd type
  * v4l2-ctl: improve --help-edid
  * v4l2-ctl: print delta to current clock in verbose mode
  * v4l2-ctl: print specific error upon failure
  * v4l2-ctl: recognize compound h264 and fwht control types
  * v4l2-ctl: remove unused struct flag_def
  * v4l2-ctl: rename vivid_uvc_meta_buf to uvc_meta_buf
  * v4l2-ctl: set  total number of native DTDs to 1
  * v4l2-ctl: subdev: Add support for the CSC API in the subdevices
  * v4l2-ctl: subdev: Add the flags to the list of supported mbus formats
  * v4l2-ctl: update EDIDs
  * v4l2-ctl: update test EDIDs
  * v4l2-ctl: vidcap: Add support for the CSC API
  * v4l2-dbg: fix control flow problem
  * v4l2grab: add command line args for other capture methods
  * v4l2grab: add querycap basic support
  * v4l2grab: add read and userptr capture methods
  * v4l2grab: fix block mode handling
  * v4l2grab: prepare it for adding support for other methods
  * v4l2grab: remove an unused var
  * v4l2grab: some code reorg
  * v4l2-info: add v4l2_info_subdev_capability
  * v4l2-info.cpp: add new flag V4L2_FMT_FLAG_ENC_CAP_FRAME_INTERVAL
  * v4l2-subdev.h: replace BIT(0) by 0x00000001
  * v4l2-tpg.patch: add clamp_t define
  * v4l2-tpg.patch: rename min/max defines to tpg_min/max
  * v4l2-utils: test cache_hints for MMAP queues
  * v4l2-utils: turn fb_formats to constexpr array
  * v4l-compliance: re-introduce NON_COHERENT and cache hints tests
  * v4l-compliance: remove NON_CONSISTENT hint test
  * v4l-helpers: don't mix enum type with int
  * v4l-utils: add missing fallthrough
  * v4l-utils: add missing static
  * v4l-utils: convert board_list to vector
  * v4l-utils: FreeBSD already defines packed
  * v4l-utils: libdvbv5: fix broken my_strlcpy calls
  * v4l-utils: patch v4l2-controls.h
  * v4l-utils: switch remote_subtest arrays to vector
  * v4l-utils: sync with latest media kernel
  * v4l-utils: sync with latest media staging tree
  * v4l-utils: sync with latest media_tree master repo
  * v4l-utils: sync with media_tree master
  * v4l-utils: sync with media_tree/master
  * v4l-utils: sync with upstream media_tree master
  * v4l-utils: update v4l2-tpg.patch
  * v4l-utils: use V4L2_TYPE_IS_CAPTURE
- remove sysmacros.patch: obsolete
* Sun Feb 21 2021 Asterios Dramis <asterios.dramis@gmail.com>
- Force C++14 as the code is not C++17 ready. Fixes GCC 11 build
  (boo#1181884).
- Don't exclude /usr/lib/udev/systemd-udevd.service.d/50-rc_keymap.conf
  for Leap 15.3.
* Tue Sep  8 2020 Hans-Peter Jansen <hpj@urpla.net>
- Exclude /usr/lib/udev/systemd-udevd.service.d/50-rc_keymap.conf
  for Leaps, it isn't installed in the first place
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.20.0:
  * v4l2-ctl: add sizeimage suboption for set-fmt-video options
  * qvidcap: Add stride option to command line
  * buildsystem: Start v4l-utils 1.19.0 development cycle
  * dvbv5-zap: Fix typo
  * v4l2-ctl: include C++ cmath header
  * ubuntu1604: add missing headers for std::exit
  * libcecutil: Remove vanished TODO file from ditribution list
  * v4l2-ctl: Do not distribute generated 32bit source
  * v4l2-compliance: Do not distribute generated 32bit source
  * libcecutil: Distribute cec-gen.pl
  * Fix broken for loop in libv4l
  * Fix for mismatched class/struct tags
  * v4l2-compliance: improve metadata capture support
  * test-media: remove left-over debug lines
  * v4l2-compliance: fail if selection is present for compressed video
  * cec-compliance: rename 'ok' to 'unknown'
  * cec-ctl/msg2ctl.pl: don't add HTNG commands to msgtable
  * cec-compliance: add --test-fuzzing option
  * test-media: update vimc tests
  * v4l-utils: sync with latest media_tree master
  * keytable: add new generated keymaps
  * msg2ctl.pl: add newline after log_msg
  * cec-follower: drop the hardcoded UI commands list
  * cec-ctl/cec-log: use new CEC_OP_UI_CMD defines
  * cec utils: support CEC_ADAP_G_CONNECTOR_INFO
  * cec-compliance/follower: use new CEC_OP_UI_CMD defines
  * utils/libcecutil: add CEC utility library
  * cec-follower: switch to the new CEC utilities library
  * cec-compliance: use the new CEC utilities library
  * cec-ctl: use the new CEC utilities library
  * utils/common/cec*: remove unused cec files
  * cec-htng(-funcs).h: move to libcecutil
  * libcecutil: do not assume building in source tree.
  * libcecutil: remove empty generated headers on failure
  * libcecutil: cec-gen.pl now generates all headers in one go
  * v4l-utils: sync to latest cec-funcs.h
  * libcecutil: spaces should be replaced by - for help_features
  * cec-compliance: move util_receive to cec-compliance.cpp
  * cec-compliance: add timeout to util_receive
  * cec-compliance: fix a bug in util_receive
  * cec-compliance: Improve the INACTIVE_SOURCE test
  * cec-follower: add INACTIVE_SOURCE support.
  * v4l2-compliance: fix read/write tests
  * cec-compliance: improve Inactive Source test
  * cec-compliance: Set OSD Name is not TV specific
  * Makefile.am: copy v4l2-tpg.h, not v4l2-tpg*
  * v4l-utils: sync with latest media_tree master
  * v4l2-info.cpp: support the new hold capture flags
  * cec-compliance: remove old tuner tests
  * cec-follower: add support for Status Request
  * cec-compliance: improve failure reporting
  * cec-follower: fix index handling
  * v4l-utils: sync with latest media_tree master
  * cec-compliance: improve the Inactive Source test
  * v4l-utils: sync with latest media_tree master
  * v4l2-compliance: better scaler detection for M2M devices
  * cec-ctl: add a --phys-addr-from-edid option
  * cec: fix Makefile.am to get the right library dependencies
  * libcecutil: convert latency values to ms
  * cec-ctl: finish --stress-test-power-cycle with active display
  * cec-compliance: make the subtest names unique
  * cec-compliance: add -e and -l options
  * cec-compliance: make test names easier to type
  * qvidcap: fix typo: fnt -> fmt
  * qvidcap: switch to RGB24 if format is unsupported
  * v4l2-ctl: support -k (concise) when showing touch data
  * v4l2-compliance: relax a 'is the DONE flag set' test
  * v4l-utils: fix sync-with-kernel: it missed pixelformats
  * qvidcap: make texts consistent
  * cec-follower: add --ignore option
  * cec-follower: support CEC 2.0 power status reporting
  * cec-compliance: test CEC 2.0 power transitions
  * cec-ctl: add --phys-addr-from-edid-poll
  * cec-compliance: return OK_PRESUMED in the power transition test
  * cec-compliance: update patch link
  * cec-compliance: change a fail to a warn
  * qvidcap: use --pixelformat instead of --pixel-format
  * cec-ctl: show PA changes with --phys-addr-from-edid-poll
  * cec-ctl: sleep 5s before retry, use cec_phys_addr_exp
  * cec: remove duplicate cec_phys_addr_exp defines
  * cec-ctl: improve --test-power-cycle test
  * cec-ctl: fix --phys-addr-from-edid-poll support
  * cec: show OSD Name with quotes around the name
  * v4l2-compliance: log the size of time_t
  * v4l2-compliance: use %%zd with sizeof(time_t)
  * v4l2-ctl/compliance: fix 32-bit g_topology casts
  * v4l2-ctl/compliance: fix 32-bit compiler warnings
  * v4l2-compliance: use a better invalid address
  * v4l2-compliance: fix uninitialized have_sel variable
  * v4l2-compliance: return ENOTTY if selection is not supported
  * cec-compliance: add invalid ioctls test
  * v4l2-compliance: add tests for invalid ioctls
  * cec-ctl/compliance: call srandom()
  * cec-compliance: '-e' alias for --expect was missing
  * cec-compliance.h: add warn_on_test, clean ups
  * cec-compliance: fail/warn if reported latency > 50ms
  * cec-compliance: add --expect-with-no-warnings
  * cec-compliance: swap -n/-N options
  * v4l-utils: remove trailing spaces
  * qvidcap: properly initialize m_curSize/Data
  * Revert "qvidcap: properly initialize m_curSize/Data"
  * qvidcap: properly initialize m_curSize/Data
  * v4l2-compliance: check source and sink pad types of a link
  * cec-compliance: clarify obscure error message
  * cec-ctl: remove trailing space in output
  * cec-ctl: add timestamps to the power-cycle tests
  * cec-ctl: improve --stress-test-power-cycle option
  * libcecutil: translate abort_msg to a message string
  * libcecutil: drop CEC_MSG_ prefix when logging messages
  * v4l2-compliance: improve USERPTR streaming tests
  * v4l2-compliance: fix bug/improve testing filler
  * v4l2-compliance: fix userptr buffer checks
  * cec-compliance: improve system_info_give_features()
  * sync with latest media_tree master
  * v4l-utils: add --enable-v4l2-compliance/ctl-32 option
  * v4l-utils: fix autoconf/automake errors
  * test-media: add -32 option
  * v4l2-compliance: fix 32 bit warnings
  * v4l2-ctl/compliance-32: fix when configuring from another dir
  * v4l2-compliance: fix typo: v4l2-ctl -> v4l2-compliance
  * cec-ctl: add 'repeats' suboption to --stress-test-power-cycle
  * cec-ctl: added polls suboption to --stress-test-power-cycle
  * cec-ctl: handle ENONET errors
  * Revert "cec-ctl: handle ENONET errors"
  * cec-ctl: set wakeup_la correctly and handle ENONET & EINVAL in stress tests
  * v4l2-compliance: fix weird formatting with -f
  * cec-ctl: don't transmit IMAGE_VIEW_ON every second
  * cec-ctl: introduce and use transmit_msg_retry()
  * cec-compliance: check for invalid transient power states
  * cec-ctl: check for incorrect state transitions
  * cec-ctl: add min-sleep suboption
  * cec-ctl: show timeouts vs Nacks
  * cec-ctl: show | instead of e or E
  * test-media: postpone the dmesg command
  * cec-follower: check both CEC_CAP_PHYS_ADDR and _CONNECTOR_INFO
  * cec-ctl: improve wait_for_pwr_state
  * cec-ctl: add physical address sanity checks
  * v4l-utils: sync with latest media_tree master
  * v4l2-compliance: fix step < 0 control check
  * v4l-utils: sync with latest media kernel
  * v4l2-compliance: zero mbus_code
  * v4l2-compliance: add tests for V4L2_CAP_IO_MC
  * v4l2-ctl: zero v4l2_fmtdesc
  * v4l-utils: sync with latest media kernel
  * gconv: fix compiler warning
  * v4l2-ctl: add missing subdev usage in --help-all
  * cec-follower: create analog channel frequencies
  * cec-follower: add tuner analog service emulation
  * cec-follower: fix bugs for tuner emulation
  * cec-follower: add tuner step increment/decrement
  * cec-follower: fix analog tuner device info update
  * cec-follower: rename freq_idx to service_idx
  * cec-follower: create digital ARIB channels
  * cec-follower: create digital ATSC channels
  * cec-follower: create digital DVB channels
  * cec-follower: add tuner digital service emulation
  * cec-follower: fix tuner step increment/decrement
  * cec-compliance: add tuner control test
  * v4l-utils: configure.ac: Avoid bashisms
  * qv4l2: Use C library file operations with v4lconvert for raw mode devices
  * cec: fix cec-log.h dependency issues
  * v4l2grab: allow using direct calls instead of libv4l
  * v4l2grab: add support for setting the fourcc code
  * keymap.h needs sys/types.h and argp.h with musl
  * v4l2-compliance: fix assert on only read/write-only controls
  * v4l2-ctl: Support query V4L2_CTRL_TYPE_AREA controls
  * v4l2-ctl: Support getting V4L2_CTRL_TYPE_AREA controls
  * v4l2-ctl: Support setting V4L2_CTRL_TYPE_AREA controls
  * v4l2-compliance: Allow all the selection targets for subdevs
  * keytable: use input_event properly
  * keytable: add compatibility for input_event_sec
  * treewide: remove bzero
  * treewide: fix redundant expressions
  * treewide: remove pointless c_str
  * dvb-sat: remove pointless abs call
  * utils: checks for empty instead of size in if
  * treewide: add extra {} to initialization
  * treewide: do not use return after else
  * treewide: fix wrong identation
  * utils: simplify bool returns
  * treewide: fix math problems
  * treewide: replace C casts with C++
  * treewide: apply performance fixes
  * utils: use bool literals
  * utils: do not use empty void with C++
  * utils: remove extra commas
  * utils: fix float equal warning
  * utils: add copy assignment operator
  * utils: initialize variable
  * utils: fix wrong format
  * utils: fix compilation with C++98
  * utils: add noreturn attribute and remove dead code
  * utils: fix implicit float conversions
  * utils: fix fallthrough warnings
  * utils: fix double promotions
  * utils: replace exit with std variant
  * cec-compliance: add missing header for clang
  * compiler.h: fix compilation with libcxx
  * compiler.h: fix compilation with clang + std=c++98 + glibcxx
  * utils: replace chr functions with std variants
  * ir-ctl: report timeout when it cannot be modified
  * keytable: do not warn if keymap not found in IR_KEYTABLE_USER_DIR
  * ir-keytable: bpf: improve rsc imon pointer decoder
  * sync v4l-utils.spec with the fedora repo
  * keytable: cannot load BPF decoders from udevd
  * 50-rc_keymap.conf prevents debian testing from booting
  * lircd2toml: warn when scancode has duplicate definitions
  * keytable: keymap without protocol is invalid
  * rc_keymap.5: improve wording around using rc_keymaps for sending
  * keytable: a bpf protocol can have parameters and no scancodes
  * Fix build failure on s390x
  * keytable: support 64 bit scancodes
  * keytable: new samsung36 bpf decoder
  * Add keymap for Samsung AK59-00125A remote
  * ir-ctl: removed nested functions to support building with clang
  * ir-ctl: allow unmodulated signal to be sent
  * keytable: "-p all" should not attempt BPF decodes that don't exist
  * v4l2-ctl: Print UVC meta info
  * v4l2-compliance: fix metadata output support
  * v4l2-compliance: Verify metadata formats
  * v4l2-ctl: support for metadata output
  * v4l2-ctl: Add Support for Touch
* Sun Jun  7 2020 Marcus Meissner <meissner@suse.com>
- libv4l-devel-32bit needs to require the shared libraries belonging
  to it, libv4l1-0-32bit + libv4l2-0-32bit + libv4l2rds0-32bit + libv4lconvert0-32bit.
  This helps Wine development (bsc#1172301)
* Sat May  2 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 1.18.1:
  Fix GCC 10 / -fno-common
- Drop upstream gcc10.patch
* Sat May  2 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Avoid symbol name clash causing qv4l2 crash - v4l2_open is defined
  by the public libv4l2 and private libv4l2utils
  * Update use_system_v4l_for_qv4l.patch
* Mon Mar  2 2020 Tomáš Chvátal <tchvatal@suse.com>
- Add patch for gcc 10 bsc#1160298:
  * gcc10.patch
* Wed Jan  8 2020 Tomáš Chvátal <tchvatal@suse.com>
- Refresh patch sysmacros.patch
- Update to 1.18.0:
  * Various fixes all around
* Mon Nov  4 2019 Stefan Seyfried <seife+obs@b1-systems.com>
- add v4l-utils-32bitfix.patch (boo#1109541)
* Sat Sep  7 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Split build of qv4l2ctl to an independent package. This allows
  building libv4l much earlier in the build cycle, as it no
  longer depends on libQt5.
  * Add use_system_v4l_for_qv4l.patch
- Drop glu BuildRequires, only used for unused test binary in
  contrib.
* Mon Oct  1 2018 schwab@suse.de
- sysmacros.patch: include <sys/sysmacros.h> for minor
* Mon Jun  4 2018 mpluskal@suse.com
- Update to version 1.14.2:
  * keytable: abi no longer set LIRC_CAN_REC_SCANCODE for raw
    devices
  * ir-ctl: abi no longer set LIRC_CAN_SEND_SCANCODE for raw
    devices
* Tue Feb  6 2018 asterios.dramis@gmail.com
- Update to version 1.14.1:
  * Lot of changes, see ChangeLog for details.
* Fri Jul  7 2017 asterios.dramis@gmail.com
- Update to version 1.12.5:
  * dvb-scan: fix the logic for multi-section handling
  From version 1.12.4:
  * libdvbv5: T2 delivery descriptor: fix wrong size of bandwidth
    field
  * desc_t2_delivery: consider valid to have a short T2 descriptor
  * desc_t2_delivery: properly handle cell and subcell tables
  * desc_t2_delivery: improve print dumps of T2 delivery
  * desc_t2_delivery: resize frequency array for subcel freqs
  * libdvbv5: add support for more PMT descriptors
  * libdvbv5: fix T2 delivery descriptor parsing in
    dvb_desc_t2_delivery_init()
* Tue Apr  4 2017 mpluskal@suse.com
- Update to version 1.12.3:
  * dvb-sat: fix rangeswitch logic
  * dvb-sat: add verbose options for LNBf settings
  * dvb-sat: add support for Invacom QPH-031 LNBf
  * pt_BR: update translation file to reflect latest changes
* Tue Feb 14 2017 mpluskal@suse.com
- Update to version 1.12.2:
  * libdvbv5: Link against libudev
  * buildsystem: Add all files to dist target
  * v4l2-ctl: Fix unneeded dot in "no hsync lock"
  * man: Fix typos in dvbv5-scan dvbv5-zap pages
  * libdvbv5: Improve vdr format output for DVB-T(2)
  * dvb-fe-tool: add an option to set maximum number of stat samples
  * libdvbv5: Fix dvb-format-convert segfault
  * ir-ctl: `strndupa' undefined with --disable-nls
- Some packaging cleanup
- Recommend dtv-scan-tables-v5 by dvb-utils
* Wed Aug  3 2016 asterios.dramis@gmail.com
- Update to version 1.10.1:
  * libdvbv5: Fix decsriptors typo
  * libv4lconvert: Exclude memsrc implementation for libjpeg-turbo
  * v4lconvert: Add "PEGATRON CORPORATION" to asus_board_vendor
- Replaced libqt5-qtbase-devel build requirement with
  pkgconfig(Qt5Core), pkgconfig(Qt5Gui), pkgconfig(Qt5OpenGL) and
  pkgconfig(Qt5Widgets).
* Sun Jun 12 2016 tchvatal@suse.com
- Run over with spec-cleaner
* Sat Jun 11 2016 asterios.dramis@gmail.com
- Update to version 1.10.0:
  * Lots of changes: See ChangeLog for details.
* Wed May 11 2016 schwab@suse.de
- Don't build qv4l2 on arm
* Fri Jan  8 2016 tchvatal@suse.com
- Version update to 1.8.1:
  * See changelog file for in-depth decription of the fixes
* Fri Sep 25 2015 mpluskal@suse.com
- Add gpg signature
- Switch to qt5 on recent releases
- Split language packages
- Update to 1.8.0
  * See ChangeLog for full list of changes
* Sun Sep 20 2015 meissner@suse.com
- Add -devel pkg to baselibs to build Wine on 64bit only distros
* Fri Sep 11 2015 asterios.dramis@gmail.com
- Update to version 1.6.3:
  * v4lconvert: Add ASUS A7Sn to upside down table
  * v4lconvert: Add ASUS A6R to upside down table
  * Synchronize with the Kernel
  * vivid-tpg.h.patch: update to match current upstream tree
  * sync-with-kernel: add include/linux/media.h
  * configure.ac: fix qv4l2 if QGLFunctions doesn't exist
  * libv4lconvert: Fix support for Y16 pixel format
* Fri Mar 13 2015 tchvatal@suse.com
- Cleanup few conditions for better readability
* Sun Feb  1 2015 asterios.dramis@gmail.com
- Update to version 1.6.2:
  * Lots of changes: See ChangeLog for details.
- Added doxygen build requirement.
- Added new subpackages dvb-utils (split from v4l-utils), libdvbv5 and
  libdvbv5-devel.
* Sat Jul 26 2014 asterios.dramis@gmail.com
- Update to version 1.2.1:
  * Lots of changes: See ChangeLog for details.
- Added alsa-devel build requirement.
- Use autoreconf to fix build in openSUSE 12.2.
- Removed bufferoverflowstrncat.patch (fixed upstream).
* Wed Jun  4 2014 asterios.dramis@gmail.com
- Update to version 1.0.1:
  * Lots of changes: See ChangeLog for details.
- Removed ImageMagick and sysfsutils-devel build requirements (not needed
  anymore).
- Added pkg-config build requirement.
- Use desktop-file-utils instead of update-desktop-files for openSUSE > 12.1.
  Added desktop-file-utils build requirement for this.
- Removed the following patches:
  * disable_rds_compilation.patch (not needed anymore).
  * udev-rules-dir.patch (fixed upstream).
  * use-openat-if-available.patch (fixed upstream).
- Added a patch "bufferoverflowstrncat.patch" to fix rpm post build check error
  "Statement might be overflowing a buffer in strncat".
* Thu Jan  2 2014 dmueller@suse.com
- fix compiled-in paths by specifying PREFIX and LIBDIR correctly
  during build
* Sat Mar 16 2013 dmueller@suse.com
- add use-openat-if-available.patch:
  * prefer openat over deprecated open syscall (fixes aarch64)
* Fri Nov  2 2012 asterios.dramis@gmail.com
- Update to version 0.8.9:
  libv4l changes:
  * libv4lconvert: Various Pixart JPEG fixes
  * libv4lconvert: Add more notebooks to the upside down device table
  Utils changes:
  * keytable: Add support for Sanyo IR and RC-5-SZ protocol
  * keytable: Add missing buttons in shipped keytables
  * v4l2-compliance, v4l-ctl, qv4l2: Sync with development branch
- Removed libdvbv5-Add-missing-includes.patch (fixed upstream).
* Wed Oct 17 2012 fcrozat@suse.com
- Add udev-rules-dir.patch and BuildRequires udev to fix build with
  new udev rules directory location.
* Wed May 30 2012 asterios.dramis@gmail.com
- Added a patch (libdvbv5-Add-missing-includes.patch) in order to fix
  compilation due to missing includes.
* Sun Apr 22 2012 asterios.dramis@gmail.com
- Update to v0.8.8
  Utils changes:
  * dvb-format-convert: fix argument check and helper message
  libv4l changes:
  * tinyjpeg: Better luminance quantization table for Pixart JPEG
  * tinyjpeg: Fix out of bounds array usage
  * libv4lconvert: Use bytesperline instead of width
  * libv4lconvert: Revert Lenovo X201 upside down table entry
  * libv4lconver: Add 06f8:301b pac7302 based cam to the quirk table
* Wed Apr 11 2012 asterios.dramis@gmail.com
- Update to v0.8.7
  Utils changes:
  * ir-keytable: Fixed file parsing errors
  * qv4l2: fix segfault when there are no inputs or outputs
  * dvb: Merged DVB tools from development branch
  libv4l changes:
  * Add some more laptop models to the upside down devices table
- Rebased disable_rds_compilation.patch to apply cleanly.
* Sun Feb 26 2012 asterios.dramis@gmail.com
- Update to v0.8.6
  libv4l changes:
  * Add support for libjpeg >= v7
  * Add new matching algorithm for upside down table
  * Add some more laptop models to the upside down devices table
  * Retry with another frame on JPEG header decode errors
  * Improved JL2005BCD support
  * Set errno to EIO if getting 4 consecutive EAGAIN convert errors
  * Make software autowhitebalance converge faster
  * Add quirk support for forced tinyjpeg fallback
- Spec file updates:
  * Added libjpeg-devel in BuildRequires: as direct dependency.
* Sun Jan 29 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
* Thu Aug 18 2011 Rene.vanPaassen@gmail.com
- Spec file updates:
  * Add udev in BuildRequires: for SLE 11 and 11 sp1 (fixes error that
    /lib/udev/rules.d is not owned by any package).
* Sat Jul 23 2011 asterios.dramis@gmail.com
- Update to v0.8.5
  Utils changes:
  * parse_em28xx_drxk.pl: New parser for dumps of em28xx with drxk frontend
  * qv4l2: Add support for bitmap controls
  * v4l2-ctl: add support for the new bitmask control type
  * v4l2-ctl: add support for the control event
  * v4l2-ctl: small bugfixes
  * v4l2-compliance: various new tests
  * lib_media_dev: various fixes / cleanups
  libv4l changes:
  * Add some more laptop models to the upside down devices table
  * Add support for SE401 pixelformat
  * Software autogain tweaks
- Rebased disable_rds_compilation.patch to apply cleanly.
* Sun Jun 26 2011 asterios.dramis@gmail.com
- Update to v0.8.4
  Utils changes:
  * Various small fixes
  * qv4l2: Add support for configuring the framerate for devices which support
    this like uvc cams
  * parse_tcpdump_log.pl: new parser for tcpdump / wireshark made usbmon dumps
  * New lib_media_dev lib, to pair audio devices with video devices (and other
    combinations) for now this lives in utils and does not get installed
    systemwide, as the API is not stable
  libv4l changes:
  * Add many more laptop models to the upside down devices table
  * Some small bugfixes
  * Add vicam cameras to list of cameras need sw auto gain + whitebalance
  * Add support for M420 pixelformat
  * Add support for Y10B pixelformat
  * Add support for JPGL pixelformat
  * Modified (rewrote) jpeg decompression code to use libjpeg[-turbo], for
    much lower cpu load when doing jpeg decompression
  * Detect usb connection speed of devices
  * Rewrite src format selection algorithm, taking bandwidth into account and
    choosing the format which will give us the lowest CPU load while still
    allowing 30 fps
  * Intercept S_PARM and redo src format selection based on new fps setting,
    potentially switching from JPG to YUYV / M420 when the app lowers the fps,
    resulting in a significant lower cpu load
- Spec file updates
  * Require libv4l in the libraries.
  * Minor other updates.
- Fixed rpmlint warning "wrong-icon-size".
- Removed the desktop file and icon for qv4l2 (they are provided by the
  package now).
- Rebased disable_rds_compilation.patch to apply cleanly.
* Sun May  8 2011 asterios.dramis@gmail.com
- Update to v0.8.3
  * Name changed to v4l-utils (libv4l + some utils).
  * Lots of changes (see ChangeLog).
- Spec file updates
  * Changes based on rpmdevtools templates and spec-cleaner run.
  * Changes to incorporate the addition of the utils.
  * Updates Licenses (based on Fedora).
- Added desktop file and icon for qv4l2 (taken from Fedora package).
- Removed libv4l-nonvoid_return.diff patch (fixed upstream).
- Added a patch to disable compilation of utils/rds (fails to compile with
  ic2-dev.h from ic2-tools).
* Thu Jun 10 2010 wittemar@googlemail.com
- build libv4l-32bit
* Mon May 17 2010 coolo@novell.com
- remove explicit version requires to non-versioned package from
  shared libraries
- buildrequire pkg-config to fix provides
* Mon Feb 22 2010 ro@suse.de
- buildfix: "control reaches end of non-void function"
* Mon Feb 22 2010 bphilips@novell.com
- Upstream doesn't provide bz2. Change back to gz in URL.
* Mon Feb 22 2010 bphilips@novell.com
- Update to v0.6.4
  - Add more laptop models to the upside down devices table
  - Add error checking to mr97310a decompression
  - Increase mr97310a minimum clockdiv upon 3 consecutive decoding errors
  - Add support for decompressing CPIA1 compressed YUV
  - Speed up autogain algorithm
- Updates from v0.6.3
  - Add more laptop models to the upside down devices table
  - Improved mr97310a decompression
  - Add support for decompressing yuv420 planar JPEG (one component per SOS,
    3 SOS per frame), this is needed for w9968cf based cams
  - Add support for STV0680 raw bayer data
- Updates from v0.6.2
  - Add more laptop models to the upside down devices table
  - Put usb id in controls shm segment name for USB devices, to better
    distuingish between devices plugged into the same port
  - Enable software whitebalance and autogain for mr97310a cameras
  - Improvements / tweaks to software autogain algorithm
* Fri Jan 15 2010 chris@computersalat.de
- cleanup spec
  * shared libs to subpkg
  * added debug_package_requires
  * bzipped source
- rpmlint
  * devel-package-with-non-devel-group
  * summary-not-capitalized
- added baselibs.conf as a source2
  o and updated
* Tue Sep  1 2009 schaeferf.obs@googlemail.com
- Update to v0.6.1
  - Add more laptop models to the upside down devices table
  - Bugfix: fixup 320x240 output for pac7302 cameras
  - Bugfix: fix reqbuf Device or Resource busy error when using v4l2_read()
  - Some applications want to use jpg format if possible, so do not hide
    it from the apps (do not assume it always needs conversion)
  - Change controls shm segment name to include the username, as it is only
    writable by the user (this means libv4l controls are per user) (Gregor Jasny)
  - Add support for decompressing sn9c2028 compressed bayer (Theodore Kilgore)
  - Report V4L2_FMT_FLAG_EMULATED in v4l2_fmtdesc flags for emulated formats
* Thu Aug  6 2009 schaeferf.obs@googlemail.com
- Update to v0.6.0
  - Software whitebalancing, automatic gain, exposure and gamma control for cams which lack this in hardware
  - Fake v4l2 controls to control all these
  - Software flipping controls
  - Recognize disabled controls and replace with fake equivalents where available
  - Add tons of laptop models to the upside down devices table
  - Add support for decompressing ov511 and ov518 "JPEG"
  - Improved pac207 decompression code
  - Support for rgb565 source format
  - Many bug fixes
- Merge spec files from drivers:webcam and openSUSE:Factory <bphilips@suse.de>
* Tue Mar 10 2009 bphilips@suse.de
- Add baselibs.conf to build -32bit packages
- Version bump to 0.5.8
  * Add support for UYVY (for USB Apple iSight) patch by Julien BLACHE
    <jb@jblache.org>
  * Remove v4lconvert_yvyu_to_yuv420 function as its functionality is
    duplicate with v4lconvert_yuyv_to_yuv420
  * Use Requires.private where appropiate in .pc files (patch by Gregor Jasny)
  * Switch to using USB-id's instead of USB product string, as not all devices
    set a unique product string. This fixes the upside down issues with
    genius e-messenger 112 cams
  * Add support for sn9c20x-i420 format patch by Vasily Khoruzhick
    <anarsoul@gmail.com>
* Thu Dec  4 2008 bphilips@suse.de
- Version bump to 0.5.7
  * Fix a nasty (and stupid) bug in the special try_fmt handling for UVC cams
  * Add some more verbose logging of various calls when asking libv4l to log
    calls to a file, to assist in (future) debugging
  libv4l-0.5.6
  * Always do a s_fmt on uvc cams even if this changes nothing, as not doing
    the s_fmt triggers a bug in the uvcvideo driver in kernel <= 2.6.28
    (with certain cams)
  libv4l-0.5.5
  * Avoid the use of try_fmt as much as possible on UVC cams, instead use the
    results of the enum_framesizes ioctl. This is because:
    1) try_fmt actually causes IO with UVC cams making apps which do lot of
    querrying of device capabilities slow (cheese)
    2) some buggy cams don't like getting lots of UVC video probes and crash
    when they do
  libv4l-0.5.4
  * Don't report DQBUF errors when errno is EAGAIN, this fixes flooding the
    screen with errors when applications use non blocking mode
  * Add support for downscaling to make apps which want low resolutions
    (skype, spcaview) happy when used with cams which can only do high
    resolutions (by Lukáš Karas <lukas.karas@centrum.cz>).
  * Add support for converting to YV12 planar (next to the already supported
    YU12 / I420)
  * Implement RGB/BGR24 -> YU/YV12 conversion
  libv4l-0.5.3
  * When conversion requires multiple passes don't alloc the needed temporary
    buffer on the stack, as some apps (ekiga) use so much stack themselves
    this causes us to run out of stack space
  libv4l-0.5.2
  * Add Philips SPC210NC to list of cams with upside down sensor, reported by
    Rieker Flaik
  * Work around some drivers (pwc) not properly reflecting what one gets after a
    s_fmt in their try_fmt answer
  * Check that s_fmt atleast gives us the width, height and pixelformat try_fmt
    promised us, and if not disable conversion
  * Only check width, height and pixelformat when checking if we are doing
    conversion, instead of doing a memcmp, as that are the only things which
    the convert code checks
  * Take into account that the buffers only contain half of the lines when
    field is V4L2_FIELD_ALTERNATE
  libv4l-0.5.1
  * Add support for software cropping from 352x288 -> 320x240 / 176x144 ->
    160x120, so that apps which will only work with vga resolutions like
    320x240 (Skype!) will work with cams/drivers which do not support cropping
    CIF resolutions to VGA resolutions in hardware. This makes all 2.6.27 gspca
    supported cams, except for the pac7302 which only does 640x480 (and skype
    wants 320x240), work with skype
  * The v4lconvert_convert function was becoming a bit of a mess, so split the
    functionailiy into separate v4lconvert_convert_pixfmt, v4lconvert_rotate and
    v4lconvert_crop functions, and make v4lconvert_convert a frontend to
    these
  * Do not link the wrapper libs against libpthread (patch from Gregor Jasny)
  libv4l-0.5.0
  * Add support for enumerating framesizes and frameintervals of emulated
    formats when the driver supports it for the real format
  * Make sure the video device always gets opened RW even if the application
    asks for RO
  * Add Genius E-Messenger 112 (093a:2476) to list of cams which have their
    sensor upside down
  libv4l-0.4.3
  * Add suport for YUYV and YVYU packed pixel formats (Jean-Francois Moine)
  * Prefer compressed pixformats for resolutions > 176x144
  libv4l-0.4.2
  * The bayer pixel order in gspca's sonixb driver was different from that in
    the sn9c102 driver from the mainline kernel, a recent gspca patch fixes
    this, adjust libv4l to match (and make it work properly with the sn9c102
    driver).
  libv4l-0.4.1
  * When the driver supports read() and we are not converting let the driver
    handle read() instead of emulating it with mmap mode
  * Fix errors and warnings when compiling with ICC (Gregor Jasny)
  * Add support to libv4lconvert for rotating images 90 (for Pixart 7302 cams)
    or 180 (Philips SPC200NC / Philips SPC300NC) degrees
  * Add support for Pixart custom JPEG format
  * Hide non public symbols (Gregor Jasny)
  * Fix and enable x86_64 asm jpeg decompress helper functions (Gregor Jasny)
* Fri Aug 15 2008 bphilips@suse.de
- Initial SuSE package
